guardCallback property

GuardCallback guardCallback
final

The callback that will be called when the guard is satisfied. It will both update the guard, notify the router and continue navigation.

Implementation

final GuardCallback guardCallback;