redirectRoute property
The PageInfo that will be used to redirect the user when the guard is not satisfied.
Implementation
final GuardedRouteGeneratingFunction redirectRoute;
The PageInfo that will be used to redirect the user when the guard is not satisfied.
final GuardedRouteGeneratingFunction redirectRoute;